@@ -265,9 +265,6 @@ GeomTextRepel <- ggproto("GeomTextRepel", Geom,
     verbose = FALSE
   ) {
 
-    # Do not draw labels for data points outside the panel
-    data <- exclude_outside(data, panel_scales)
-
     if (parse) {
       data$label <- parse_safe(as.character(data$label))
     }
